@@ -7,13 +7,13 @@ module Haml
 
       def copy_view_files
         if ::Rails.version.to_s >= "4.2.0"
-          view_base_path = File.join("app/views", class_path, file_name)
+          view_base_path = File.join("app/views", class_path, file_name + "_mailer")
           empty_directory view_base_path
 
-          if self.behavior == :invoke
+          if behavior == :invoke
             formats.each do |format|
-              layout_path = File.join("app/views/layouts", filename_with_extensions("mailer", format))
-              template filename_with_extensions(:layout, format), layout_path
+              layout_path = File.join("app/views/layouts", class_path, filename_with_extensions("mailer", format))
+              template filename_with_extensions(:layout, format), layout_path unless File.exist?(layout_path)
             end
           end
 
